from enum import Enum

class NodeSize(Enum):
    SMALL = "small"
    MEDIUM = "medium"
    LARGE = "large"

class Language(Enum):
    PYTHON = "py"
    JAVASCRIPT = "js"
    TYPESCRIPT = "ts"
    CPP = "cpp"
